@@ -179,7 +179,7 @@ def warnLater(msg: str, type_=Warning):
   if not usingPostponedErrors:
     warn(msg, type_)
   else:
-    QtCore.QTimer.singleShot(0, lambda: warn(msg, type_))
+    QtCore.QTimer.singleShot(0, lambda: warn(msg, type_, stacklevel=2))
 
 def pascalCaseToTitle(name: str, addSpaces=True) -> str:
   """
@@ -259,7 +259,11 @@ def paramValues(param: Parameter, includeDefaults=False, includeKeys=()):
   """
   outDict = {}
   val = param.value()
-  if includeDefaults or val != param.defaultValue():
+  # Overloaded group parameters have no 'value' state, but do have children. Force this to
+  # fall through to bottom block
+  if (includeDefaults or val != param.defaultValue()
+      and not param.hasChildren()
+  ):
     # Some values are not well represented as text, so call 'saveState' to ensure they work
     state = param.saveState()
     outDict[param.name()] = state['value']
