@@ -109,12 +109,9 @@ class ShortcutParameterItem(ActionParameterItem):
     # reason
     super().__init__(param, depth)
     btn: QtWidgets.QPushButton = self.button
-    btn.setToolTip(param.opts.get('tip', ''))
     self.setText(0, '')
     owner = param.opts.get('ownerObj', _Global)
-    if param.value() is None or not ShortcutParameter.REGISTRY:
-      return
-    # Else: shortcut exists to be registered
+    # Add things like icon and help text
     prjOpts = PrjParam(**param.opts)
     ButtonCollection.createBtn(prjOpts, baseBtn=self.button, namePath=(clsNameOrGroup(owner),))
 
@@ -160,6 +157,9 @@ class ShortcutKeySeqParameter(ActionParameter):
   itemClass = ShortcutKeySeqParameterItem
 
   def __init__(self, **opts):
+    # TODO: Find way to get shortcuts working well with general shortcut editor.
+    #  for now, just make sure no shortcuts are registered
+    opts.pop('value', None)
     super().__init__(**opts)
     self.isActivateConnected = False
 
