@@ -503,7 +503,7 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
         or np.any(xyCoord < 0)
         or np.any(xyCoord > np.array(self.imgItem.image.shape[:2][::-1]) - 1)):
       return
-    imgValue = self.imgItem.image[xyCoord[1], xyCoord[0],...].astype(int)
+    imgValue = self.imgItem.image[xyCoord[1], xyCoord[0],...]
     self.updateCursorInfo(xyCoord, imgValue)
     self.sigMouseMoved.emit(xyCoord)
 
@@ -517,11 +517,10 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
     self.pxColorLbl.setText(f'Pixel Color: {pxValue}')
     if self.imgItem.qimage is None:
       return
-    # Cheap way of splitting the int32 return value into uint8 RGBA
-    imColor = np.array([self.imgItem.qimage.pixel(*xyPos)], 'uint32').view('uint8')
-    grayClr = np.mean(imColor[:3])
+    imColor = self.imgItem.qimage.pixelColor(*xyPos)
+    grayClr = QtGui.qGray(imColor.rgb())
     fontColor = 'black' if grayClr > 127 else 'white'
-    self.pxColorLbl.setStyleSheet(f'background:rgba{tuple(imColor)}; color:{fontColor}')
+    self.pxColorLbl.setStyleSheet(f'background:{imColor.name()}; color:{fontColor}')
 
   def setImage(self, imgSrc: t.Union[FilePath, np.ndarray]=None):
     """
